## cdist-type__config_file(7)

### Steven Armstrong

`<steven-cdist--@--armstrong.cc>`

## 1. NAME

cdist-type__config_file - manages config files

## 2. DESCRIPTION

Deploy config files using the file type. Run the given code if the files changes.

## 3. REQUIRED PARAMETERS

None.

## 4. OPTIONAL PARAMETERS

group
  see cdist-type__file
mode
  see cdist-type__file
onchange
  the code to run if the file changes
owner
  see cdist-type__file
source
  Path to the config file. If source is - (dash), take what was written to stdin as the config file content.
state
  see cdist-type__file

## 5. EXAMPLES

    __config_file /etc/consul/conf.d/watch_foo.json \
       --owner root --group consul --mode 640 \
       --source "$__type/files/watch_foo.json" \
       --state present \
       --onchange 'service consul status >/dev/null && service consul reload || true'

## 6. SEE ALSO

- cdist-type(7)
- cdist-type__file(7)

## 7. COPYING

Copyright (C) 2015 Steven Armstrong. Free use of this software is granted under the terms of the GNU General Public License version 3 (GPLv3).